//------------------------------------------------------
//------------------------------------------------------
//   
//  AVRLIB-DEMO
//  For avrlib and Wiring development board.
//  
//
//  File:     analogin.c
//  Author:   Juan Reyes    juanig-at-ccrma-stanford_edu
//
//  Date:     July 3, 2008
//
//  Notes:
//-----------------------------------------------------
//  USING THE WIRING DEVELOPMENT BOARD, ANALOG INPUTS 
//  PORTF IN ATMEGA128 TO PROCESS SENSOR DATA AND
//  MEASURE IT USING DIGITAL OUTPUTS
//
//-----------------------------------------------------
//  Layout of ports in Wiring board correspond with
//  ATMega128 as follows:
//
//  ATMega128                WIRING
//  =========                ======
//  
//  PORTD                    PORT-0
//  PORTC                    PORT-1
//  PORTF                    ANALOG IN
//  PORTG                    BUILT-IN LED
//-----------------------------------------------------
//  Layout of analog pins in Wiring board correspond with
//  ATMega128 as follows:
//
//  Ch0                   W-APIN0
//  Ch1                   W-APIN1
//   .                      .
//  Ch7                   W-APIN7
//
//   Function a2dConvert10bit(Ch) reads and converts analog
//   values.
//
//-----------------------------------------------------
//  More information about Wiring board:
//
//  http://wiring.org.co/hardware/index.html
//  
//-----------------------------------------------------
//  Information about functions used here and avrlib:
// 
//  ~/avrlib/examples/a2d/a2dtest.c
//
//  
//*********************************************************
//   Description:
//   ============
//
//   This program will read sensor data on pin0 (Ch 0) of 
//   PORTA, analog port on Wiring board. If values are low
//   it will light a GREEN LED. If values are in the middle  
//   range it will light a YELLOW LED.If values are too high,
//   it will light a RED LED. LEDS are connected on PORTD 
//   pin0, pin1, pin2.You can use a photo resistor or a POT
//   for this purpose.
//   
//
//   Information about analog sensors and Wiring:
//   http://wiring.org.co/learning/examples/
//
//
//*********************************************************


#include <avr/io.h>
#include <avr/pgmspace.h>

#include "global.h"
#include "timer128.h"    // use timer128.h for ATMega128
#include "a2d.h"

int main(void)
{
  u16 a2dval;
  u08 lightn;
  
  // Initialize libraries
  timerInit();
    
  // ATOD STUFF
  a2dInit();
  
  // set PORTF pins to input (for ADC) 
  outb(DDRF, 0x00);        
  // turn pull-ups off 
  outb(PORTF, 0x00);   

  // set PORTD as OUTPUT
  outb(DDRD, 0xFF);
  // set pull-ups
  outb(PORTD, 0xF0);
  
  
  while(1) {
    // Read sensor value using a2dConvert10bit(ch).
    //
    // a2dConvert10bit(ch) converts on A/D channel# ch, 
    // and returns 10-bit values from 0 to 1024

    a2dval = a2dConvert10bit(0);
    
    // Check for thresholds in sensor values
    //

    if (a2dval < 500) lightn=0;
    if ((a2dval >= 500) && (a2dval < 850))  { 
      lightn=1;
    }
    if (a2dval >= 850) lightn=2;
    
    //
    // Turn ON and OFF LEDS according to 
    // thresholds

    switch(lightn) {  // switch 'C' statement
    case 0 : 
      sbi(PORTD,2);   // Turn GREEN LED ON
      cbi(PORTD,1);   // Others OFF
      cbi(PORTD,0);  
      timerPause(10);
      break;
    case 1 :
      sbi(PORTD,1);   // Turn YELLOW LED ON
      cbi(PORTD,0);   // Others OFF
      cbi(PORTD,2);  
      timerPause(10);
      break;
    case 2 :
      sbi(PORTD,0);   // Turn RED LED ON
      cbi(PORTD,1);   // Others OFF
      cbi(PORTD,2);  
      timerPause(10);
      break;
    default :
      break;
    }
  }
  return 0;
}





