//------------------------------------------------------
//------------------------------------------------------
//   
//  AVRLIB-DEMO
//  For avrlib and Wiring development board.
//  
//
//  File:     button.c
//  Author:   Juan Reyes    juanig-at-ccrma-stanford_edu
//  Based on: 'button.c' by Michael Gurevich \& Wendy Ju         
//  Date:     June 25, 2008
//
//  Notes:
//-----------------------------------------------------
//  USING THE WIRING DEVELOPMENT BOARD, BUILT-IN LED
//  IN PIN 48 PORT D SHOULD LIGHT WHEN BUTTON PRESSED.
//
//-----------------------------------------------------
//  Layout of ports in Wiring board correspond with
//  ATMega128 as follows:
//
//  ATMega128                WIRING
//  =========                ======
//  
//  PORTD                    PORT-0
//  PORTC                    PORT-1
//  PORTA                    PORT-2
//  PORTB                    PORT-3
//  PORTE                    PORT-4
//  PORTF                    PORT-5
//  PORTG                    PORT-6
//-----------------------------------------------------
//  Layout of pins in Wiring board correspond with
//  ATMega128 as follows:
//
//  px0                   WPIN0
//  px1                   WPIN1
//   .                      .
//  px7                   WPIN7
//
//  Where x = {a,b,...,g}
//
//-----------------------------------------------------
//  More information about Wiring board:
//
//  http://wiring.org.co/hardware/index.html
//  
//-----------------------------------------------------
//  Information about functions used here and avrlib:
// 
//  ~/avrlib/examples/basic_io/basiciotest.c
//  
//  
//
//*********************************************************
//   Description:
//   ============
//
//   This program will turn on/off the built in led (pin48) 
//   using a hardware swicth on a breadboard. For circuit 
//   diagram look at:
//   http://wiring.org.co/learning/examples/switch.html
//
//*********************************************************


//compiler includes
#include <avr/io.h>
#include <avr/interrupt.h>

//avrlib includes
#include "global.h"


//function prototypes:

int checkButton(int button);
void setLED(u08 whichLED, u08 on);

int main(void)
{

  //  PORTC (Port1 Wiring) is set as INPUT.
  outb(DDRC, 0x00);
  //  PORTG is set as OUTPUT.
  outb(DDRG, 0xFF);
	  

  //loop forever
  while (1) {
    
    setLED(0, checkButton(0));

	} 
  return 0;
}
int checkButton(button) {
  
  return (! bit_is_set(PINC,button));
  /* Logical negation is because when the button is pushed, the pin
     is drawn to ground, so the button is "on" when the bit is zero. */
}

void setLED(u08 whichLED, u08 on) {
  if (on) {
    //light the LED
    cbi(PORTG,whichLED);
  } else {
    //turn off the LED
    sbi(PORTG,whichLED);
  }
}



