//-------------------------------------------------------
//   
//  AVRLIB-DEMO
//  For avrlib and Wiring development board.
//  
//
//  File:     traffic.c
//  Author:   Juan Reyes  juanig_at_ccrma_stanford_edu
//  Date:     19-Jun-2008
//
//
//  Notes:
//  ======
//-------------------------------------------------------
//
//  USING THE WIRING DEVELOPMENT BOARD, 
// 
//  PORT-0 on Wiring is PORTD on ATMega128
// 
//  PORTD is set to OUTPUT
//
//-------------------------------------------------------
//
//
//  Description:
//  ============
//********************************************************
//
//  This program flashes LEDS connected to Port0 Pin0~2
//  on Wiring boards.
//
//  On a protoboard connect three colored leds to Wiring's 
//  Pin-0,pin1,and Pin2. Wires form these pins are hooked
//  to the anode (positive leg) of each LED respectively.
//  The other legs are wired to the ground (negative) pin
//  of Wiring. Make sure you have a resistor (300 Ohms) 
//  between the leg and graound signal. 
//
//  More information on:
//  http://wiring.org.co/learning/examples/led_blinks.html
//
//********************************************************

//compiler includes
#include <avr/io.h>
#include <avr/interrupt.h>

//avrlib includes
#include "global.h"
#include "timer.h"


int main(void)
{
  // Delays
  u16 delayRed, delayYellow, delayGreen;
  delayRed=5000;
  delayYellow=800;
  delayGreen=10000;

  // wiring pins
  u08 wpin0,wpin1,wpin2;
  wpin0=0;  // Red Led
  wpin1=1;  // Yellow Led
  wpin2=2;  // Green Led

  // set PORTD as OUTPUT
        outb(DDRD, 0xFF);
	// set pull-ups
	outb(PORTD, 0xF0);
	// initialize the timer library
	timerInit();

	//loop forever
	while (1) {
	  sbi(PORTD,wpin2);        // sets bit HIGH, Led ON
	  timerPause(delayGreen);  // Hold Led ON
	  cbi(PORTD,wpin2);        // sets bit LOW, Led OFF
	  
	  sbi(PORTD,wpin1);
    	  timerPause(delayYellow);
	  cbi(PORTD,wpin1);

	  sbi(PORTD,wpin0);
	  timerPause(delayRed);
	  cbi(PORTD,wpin0);
	} 
	
	return 0;
}

